@@ -64,7 +64,7 @@ async def main():
                     migrations_path=Path("")
                 )))
     # router = YamlRouter(Path("../applyed_files/config/routing.yaml"), chain)
-    router = DictRouter(routes_dict, chain, versioning=False)
+    router = DictRouter(routes_dict, chain)
     workers = create_io_workers(container.app_config.server(), router, workers_num=2)
     subscribe_worker_rt_callback(*workers, event_type=AeEvent, callback=resolve_send_event, use_nested_classes=True)
 
